"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var _ = require("lodash");
var os = require("os");
var Raven = require("raven");
var Promise = require("bluebird");
var common_tags_1 = require("common-tags");
var patterns = require("./utils/patterns");
var captureException = Promise.promisify(Raven.captureException, { context: Raven });
function hasCode(error) {
    return error.code != null;
}
function treatFailedBindingAsMissingModule(error) {
    if (error.message.startsWith('Could not locate the bindings file.')) {
        error.code = 'MODULE_NOT_FOUND';
    }
}
function interpret(error) {
    if (!(error instanceof Error)) {
        return;
    }
    treatFailedBindingAsMissingModule(error);
    if (hasCode(error)) {
        var errorCodeHandler = messages[error.code];
        var message = errorCodeHandler && errorCodeHandler(error);
        if (message) {
            return message;
        }
        if (!_.isEmpty(error.message)) {
            return error.code + ": " + error.message;
        }
    }
    else {
        return error.message;
    }
}
var messages = {
    EISDIR: function (error) { return "File is a directory: " + error.path; },
    ENOENT: function (error) { return "No such file or directory: " + error.path; },
    ENOGIT: function () {
        return (_a = ["\n\t\tGit is not installed on this system.\n\t\tHead over to http://git-scm.com to install it and run this command again."], _a.raw = ["\n\t\tGit is not installed on this system.\n\t\tHead over to http://git-scm.com to install it and run this command again."], common_tags_1.stripIndent(_a));
        var _a;
    },
    EPERM: function () {
        return (_a = ["\n\t\tYou don't have enough privileges to run this operation.\n\t\t", "\n\n\t\tIf this is not the case, and you're trying to burn an SDCard, check that the write lock is not set."], _a.raw = ["\n\t\tYou don't have enough privileges to run this operation.\n\t\t",
            "\n\n\t\tIf this is not the case, and you're trying to burn an SDCard, check that the write lock is not set."], common_tags_1.stripIndent(_a, os.platform() === 'win32'
            ? 'Run a new Command Prompt as administrator and try running this command again.'
            : 'Try running this command again prefixing it with `sudo`.'));
        var _a;
    },
    EACCES: function (e) { return messages.EPERM(e); },
    ETIMEDOUT: function () {
        return 'Oops something went wrong, please check your connection and try again.';
    },
    MODULE_NOT_FOUND: function () {
        return (_a = ["\n\t\tPart of the CLI could not be loaded. This typically means your CLI install is in a broken state.\n\t\t", "\n\t"], _a.raw = ["\n\t\tPart of the CLI could not be loaded. This typically means your CLI install is in a broken state.\n\t\t",
            "\n\t"], common_tags_1.stripIndent(_a, os.arch() === 'x64'
            ? 'You can normally fix this by uninstalling and reinstalling the CLI.'
            : (_b = ["\n\t\t\t\tYou're using an unsupported architecture (", "), so this is typically caused by missing native modules.\n\t\t\t\tReinstalling may help, but pay attention to errors in native module build steps en route.\n\t\t\t"], _b.raw = ["\n\t\t\t\tYou're using an unsupported architecture (", "), so this is typically caused by missing native modules.\n\t\t\t\tReinstalling may help, but pay attention to errors in native module build steps en route.\n\t\t\t"], common_tags_1.stripIndent(_b, os.arch()))));
        var _a, _b;
    },
    ResinExpiredToken: function () {
        return (_a = ["\n\t\tLooks like your session token is expired.\n\t\tPlease try logging in again with:\n\t\t\t$ resin login"], _a.raw = ["\n\t\tLooks like your session token is expired.\n\t\tPlease try logging in again with:\n\t\t\t$ resin login"], common_tags_1.stripIndent(_a));
        var _a;
    },
};
exports.handle = function (error) {
    var message = interpret(error);
    if (message == null) {
        return;
    }
    if (process.env.DEBUG) {
        message = error.stack;
    }
    patterns.printErrorMessage(message);
    return captureException(error)
        .timeout(1000)
        .catch(function () {
    })
        .finally(function () { return process.exit(error.exitCode || 1); });
};
//# sourceMappingURL=errors.js.map